@@ -25,6 +25,8 @@
 #include "configurationdialogadd.h"
 
 #include <kdebug.h>
+#include <QErrorMessage>
+#include <QTimer>
 
 
 using namespace feedsync;
@@ -137,3 +139,4 @@ void ConfigurationDialogAdd::slotUpdateUI()
     }
 }
 
+#include "configurationdialogadd.moc"
