@@ -37,9 +37,9 @@ class EntriesCountDialog: public KDialog
 {
     Q_OBJECT
 public:
-    explicit EntriesCountDialog( QWidget *parent = 0 );
+    EntriesCountDialog( QWidget *parent = 0 );
     ~EntriesCountDialog();
-    int count() const;
+    int count();
 
 private:
     Ui::EntriesCountDialogBase ui;
