@@ -244,7 +244,7 @@ bool MailClient::send( const KPIMIdentities::Identity &identity,
   const int transportId = transport->id();
 
   // gather config values
-  KConfig config( "mailviewerrc" );
+  KConfig config( "kmail2rc" );
 
   KConfigGroup configGroup( &config, QLatin1String( "Invitations" ) );
   const bool outlookConformInvitation = configGroup.readEntry( "LegacyBodyInvites",
