@@ -22,7 +22,7 @@
 #include "mainwindow.h"
 #include "mainwidget.h"
 
-#include <QToolBar>
+#include <QtGui/QToolBar>
 
 #include <akonadi/control.h>
 
