@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,105 +19,106 @@
 
 #include <kglobal.h>
 #include <kpimidentities/identitymanager.h>
-#include <messagecomposer/sender/akonadisender.h>
-#include <mailcommon/folder/foldercollectionmonitor.h>
+#include <messagecomposer/akonadisender.h>
+#include <mailcommon/foldercollectionmonitor.h>
 #include <akonadi/session.h>
 #include <akonadi/entitytreemodel.h>
 #include <akonadi/entitymimetypefiltermodel.h>
 #include <akonadi/changerecorder.h>
 
 ImportWizardKernel::ImportWizardKernel( QObject *parent )
-    : QObject( parent )
+  : QObject( parent )
 {
-    mMessageSender = new MessageComposer::AkonadiSender( this );
-    mIdentityManager = new KPIMIdentities::IdentityManager( false, this );
-    Akonadi::Session *session = new Akonadi::Session( "ImportWizard Kernel ETM", this );
-    mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor( session, this );
+  mMessageSender = new AkonadiSender( this );
+  mIdentityManager = new KPIMIdentities::IdentityManager( false, this );
+  mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor( this );
 
-    mEntityTreeModel = new Akonadi::EntityTreeModel( folderCollectionMonitor(), this );
-    mEntityTreeModel->setIncludeUnsubscribed( false );
-    mEntityTreeModel->setItemPopulationStrategy( Akonadi::EntityTreeModel::LazyPopulation );
+  Akonadi::Session *session = new Akonadi::Session( "ImportWizard Kernel ETM", this );
+  folderCollectionMonitor()->setSession( session );
+  mEntityTreeModel = new Akonadi::EntityTreeModel( folderCollectionMonitor(), this );
+  mEntityTreeModel->setIncludeUnsubscribed( false );
+  mEntityTreeModel->setItemPopulationStrategy( Akonadi::EntityTreeModel::LazyPopulation );
 
-    mCollectionModel = new Akonadi::EntityMimeTypeFilterModel( this );
-    mCollectionModel->setSourceModel( mEntityTreeModel );
-    mCollectionModel->addMimeTypeInclusionFilter( Akonadi::Collection::mimeType() );
-    mCollectionModel->setHeaderGroup( Akonadi::EntityTreeModel::CollectionTreeHeaders );
-    mCollectionModel->setDynamicSortFilter( true );
-    mCollectionModel->setSortCaseSensitivity( Qt::CaseInsensitive );
+  mCollectionModel = new Akonadi::EntityMimeTypeFilterModel( this );
+  mCollectionModel->setSourceModel( mEntityTreeModel );
+  mCollectionModel->addMimeTypeInclusionFilter( Akonadi::Collection::mimeType() );
+  mCollectionModel->setHeaderGroup( Akonadi::EntityTreeModel::CollectionTreeHeaders );
+  mCollectionModel->setDynamicSortFilter( true );
+  mCollectionModel->setSortCaseSensitivity( Qt::CaseInsensitive );
 }
 
 KPIMIdentities::IdentityManager *ImportWizardKernel::identityManager()
 {
-    return mIdentityManager;
+  return mIdentityManager;
 }
 
-MessageComposer::MessageSender *ImportWizardKernel::msgSender()
+MessageSender *ImportWizardKernel::msgSender()
 {
-    return mMessageSender;
+  return mMessageSender;
 }
 
 Akonadi::EntityMimeTypeFilterModel *ImportWizardKernel::collectionModel() const
 {
-    return mCollectionModel;
+  return mCollectionModel;
 }
 
 KSharedConfig::Ptr ImportWizardKernel::config()
 {
-    return KGlobal::config();
+  return KGlobal::config();
 }
 
 void ImportWizardKernel::syncConfig()
 {
-    Q_ASSERT( false );
+  Q_ASSERT( false );
 }
 
 MailCommon::JobScheduler* ImportWizardKernel::jobScheduler() const
 {
-    Q_ASSERT( false );
-    return 0;
+  Q_ASSERT( false );
+  return 0;
 }
 
 Akonadi::ChangeRecorder *ImportWizardKernel::folderCollectionMonitor() const
 {
-    return mFolderCollectionMonitor->monitor();
+  return mFolderCollectionMonitor->monitor();
 }
 
 void ImportWizardKernel::updateSystemTray()
 {
-    Q_ASSERT( false );
+  Q_ASSERT( false );
 }
 
 bool ImportWizardKernel::showPopupAfterDnD()
 {
-    return false;
+  return false;
 }
 
 qreal ImportWizardKernel::closeToQuotaThreshold()
 {
-    return 80;
+  return 80;
 }
 
 QStringList ImportWizardKernel::customTemplates()
 {
-    Q_ASSERT( false );
-    return QStringList();
+  Q_ASSERT( false );
+  return QStringList();
 }
 
 bool ImportWizardKernel::excludeImportantMailFromExpiry()
 {
-    Q_ASSERT( false );
-    return true;
+  Q_ASSERT( false );
+  return true;
 }
 
 Akonadi::Entity::Id ImportWizardKernel::lastSelectedFolder()
 {
-    Q_ASSERT( false );
-    return Akonadi::Entity::Id();
+  Q_ASSERT( false );
+  return Akonadi::Entity::Id();
 }
 
 void ImportWizardKernel::setLastSelectedFolder(const Akonadi::Entity::Id& col)
 {
-    Q_UNUSED(col);
+  Q_UNUSED(col);
 }
 
 
