@@ -48,7 +48,8 @@ ThunderbirdSettings::ThunderbirdSettings( const QString& filename, ImportWizard
          line.contains(QLatin1String("mailnews."))||
          line.contains(QLatin1String("mail.compose."))||
          line.contains(QLatin1String("mail.spellcheck")) ||
-         line.contains(QLatin1String("ldap_"))) {
+         line.contains(QLatin1String("ldap_")) ||
+         line.contains(QLatin1String("mail.biff."))) {
         insertIntoMap( line );
       }
     } else {
@@ -178,6 +179,14 @@ void ThunderbirdSettings::readGlobalSettings()
   } else {
     addKmailConfig(QLatin1String("Spelling"),QLatin1String("backgroundCheckerEnabled"),false);
   }
+  const QString mailPlaySoundStr = QLatin1String("mail.biff.play_sound");
+  if(mHashConfig.contains(mailPlaySoundStr)) {
+    const bool mailPlaySound = mHashConfig.value(mailPlaySoundStr).toBool();
+    addKmailConfig(QLatin1String("General"),QLatin1String("beep-on-mail"), mailPlaySound);
+  } else {
+    //Default value in thunderbird
+    addKmailConfig(QLatin1String("General"),QLatin1String("beep-on-mail"), true);
+  }
 }
 
 void ThunderbirdSettings::addAuth(QMap<QString, QVariant>& settings, const QString & argument, const QString &accountName )
@@ -362,12 +371,11 @@ void ThunderbirdSettings::readAccount()
       addToManualCheck(agentIdentifyName,true);
     } else if ( type == QLatin1String( "none" ) ) {
       //FIXME look at if we can implement it
+      //Local folder.
       kDebug()<<" account type none!";
-      continue;
     } else if (type == QLatin1String("movemail")) {
       kDebug()<<" movemail accound found and not implemented in importthunderbird";
-      continue;
-      //TODO
+      //MailBox ?
     } else if (type == QLatin1String("rss")) {
       //TODO when akregator2 will merge in kdepim
       kDebug()<<" rss resource needs to be implemented";
