@@ -1,25 +1,25 @@
 /*
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+  Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
+  This library is free software; you can redistribute it and/or modify it
+  under the terms of the GNU Library General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or (at your
+  option) any later version.
 
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
+  This library is distributed in the hope that it will be useful, but WITHOUT
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+  License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to the
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+  02110-1301, USA.
 */
 
 #include "contactswitcher.h"
 
-#include <klocale.h>
+#include <KLocale>
 
 #include <QtGui/QAbstractItemView>
 #include <QtGui/QHBoxLayout>
@@ -27,13 +27,24 @@
 #include <QtGui/QPushButton>
 
 ContactSwitcher::ContactSwitcher( QWidget *parent )
-  : QWidget( parent ),
-    mView( 0 )
+  : QWidget( parent ), mView( 0 )
 {
   QHBoxLayout *layout = new QHBoxLayout( this );
 
-  mPreviousButton = new QPushButton( i18nc( "Previous contact", "Previous" ) );
-  mNextButton = new QPushButton( i18nc( "Next contact", "Next" ) );
+  mPreviousButton = new QPushButton( i18nc( "@action:button Previous contact", "Previous" ) );
+  mPreviousButton->setToolTip(
+    i18nc( "@info:tooltip", "Move to the previous contact in the list" ) );
+  mPreviousButton->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Press this button to move to the previous contact in the list." ) );
+
+  mNextButton = new QPushButton( i18nc( "@action:button Next contact", "Next" ) );
+  mNextButton->setToolTip(
+    i18nc( "@info:tooltip", "Move to the next contact in the list" ) );
+  mNextButton->setWhatsThis(
+    i18nc( "@info:whatsthis",
+            "Press this button to move to the next contact in the list." ) );
+
   mStatusLabel = new QLabel();
 
   layout->addWidget( mPreviousButton );
@@ -60,14 +71,16 @@ void ContactSwitcher::setView( QAbstractItemView *view )
 
 void ContactSwitcher::nextClicked()
 {
-  if ( !mView || !mView->model() )
+  if ( !mView || !mView->model() ) {
     return;
+  }
 
   const QModelIndex index = mView->selectionModel()->currentIndex();
 
   int row = 0;
-  if ( index.isValid() )
+  if ( index.isValid() ) {
     row = index.row() + 1;
+  }
 
   mView->selectionModel()->setCurrentIndex( mView->model()->index( row, 0 ),
                                             QItemSelectionModel::Rows |
@@ -78,14 +91,16 @@ void ContactSwitcher::nextClicked()
 
 void ContactSwitcher::previousClicked()
 {
-  if ( !mView || !mView->model() )
+  if ( !mView || !mView->model() ) {
     return;
+  }
 
   const QModelIndex index = mView->selectionModel()->currentIndex();
 
   int row = 0;
-  if ( index.isValid() )
+  if ( index.isValid() ) {
     row = index.row() - 1;
+  }
 
   mView->selectionModel()->setCurrentIndex( mView->model()->index( row, 0 ),
                                             QItemSelectionModel::Rows |
@@ -96,19 +111,22 @@ void ContactSwitcher::previousClicked()
 
 void ContactSwitcher::updateStatus()
 {
-  if ( !mView || !mView->model() )
+  if ( !mView || !mView->model() ) {
     return;
+  }
 
   const QModelIndex index = mView->selectionModel()->currentIndex();
 
   int row = 0;
-  if ( index.isValid() )
+  if ( index.isValid() ) {
     row = index.row();
+  }
 
   mPreviousButton->setEnabled( row != 0 );
-  mNextButton->setEnabled( row != (mView->model()->rowCount() - 1) );
+  mNextButton->setEnabled( row != ( mView->model()->rowCount() - 1 ) );
 
-  mStatusLabel->setText( i18n( "%1 out of %2", row + 1,  mView->model()->rowCount() ) );
+  mStatusLabel->setText( i18nc( "@info:status",
+                                "%1 out of %2", row + 1, mView->model()->rowCount() ) );
 }
 
 #include "contactswitcher.moc"
