@@ -1,7 +1,7 @@
 /*
  *  eventlistview.cpp  -  base class for widget showing list of alarms
  *  Program:  kalarm
- *  Copyright © 2007-2011 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2012 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ void EventListView::select(Akonadi::Item::Id eventId)
 #else
 void EventListView::select(const QString& eventId, bool scrollToEvent)
 {
-    select(eventModel()->eventIndex(eventId), scrollToEvent);
+    select(eventFilterModel()->eventIndex(eventId), scrollToEvent);
 }
 #endif
 
