@@ -411,8 +411,8 @@ class KMComposeWin : public KMail::Composer
     void slotConfigChanged();
 
     void slotPrintComposeResult( KJob *job );
-
-    void slotEncryptChiasmusToggled( bool );
+    
+    //void slotEncryptChiasmusToggled( bool );
 
     void slotSendFailed( const QString& msg );
     void slotSendSuccessful();
@@ -597,13 +597,10 @@ class KMComposeWin : public KMail::Composer
     QGridLayout *mGrid;
     QString mTextSelection;
     QString mCustomTemplate;
-    QAction *mOpenId, *mViewId, *mRemoveId, *mSaveAsId, *mPropertiesId,
-            *mEditAction, *mEditWithAction;
     bool mLastSignActionState, mLastEncryptActionState, mSigningAndEncryptionExplicitlyDisabled;
     bool mLastIdentityHasSigningKey, mLastIdentityHasEncryptionKey;
     Akonadi::Collection mFolder;
     long mShowHeaders;
-    bool mConfirmSend;
     bool mForceDisableHtml;     // Completely disable any HTML. Useful when sending invitations in the
                                 // mail body.
     int mNumHeaders;
@@ -637,7 +634,7 @@ class KMComposeWin : public KMail::Composer
     QSplitter *mSnippetSplitter;
     QByteArray mOriginalPreferredCharset;
 
-    KToggleAction *mEncryptChiasmusAction;
+    //KToggleAction *mEncryptChiasmusAction;
 
     Message::Composer *mDummyComposer;
     // used for auto saving, printing, etc. Not for sending, which happens in ComposerViewBase
