@@ -397,7 +397,8 @@ bool KMKernel::handleCommandLine( bool noArgsOpensReader )
   if (args->isSet("msg"))
   {
      mailto = true;
-     messageFile.setPath( args->getOption("msg") );
+     const QString file = args->getOption("msg");
+     messageFile = makeAbsoluteUrl(file);
   }
 
   if (args->isSet("body"))
@@ -651,7 +652,7 @@ int KMKernel::openComposer( const QString &to, const QString &cc,
       }
   }
 
-  KMail::Composer * cWin = KMail::makeComposer( msg, context );
+  KMail::Composer * cWin = KMail::makeComposer( msg, false, false, context );
   if (!to.isEmpty())
     cWin->setFocusToSubject();
   KUrl::List attachURLs = KUrl::List( attachmentPaths );
@@ -749,8 +750,8 @@ int KMKernel::openComposer (const QString &to, const QString &cc,
     }
   }
 
-  KMail::Composer * cWin = KMail::makeComposer( KMime::Message::Ptr(), context );
-  cWin->setMsg( msg, !isICalInvitation /* mayAutoSign */ );
+  KMail::Composer * cWin = KMail::makeComposer( KMime::Message::Ptr(), false, false,context );
+  cWin->setMessage( msg, false, false, !isICalInvitation /* mayAutoSign */ );
   cWin->setSigningAndEncryptionDisabled( isICalInvitation
       && MessageViewer::GlobalSettings::self()->legacyBodyInvites() );
   if ( noWordWrap )
@@ -803,7 +804,7 @@ QDBusObjectPath KMKernel::openComposer( const QString &to, const QString &cc,
 
   const KMail::Composer::TemplateContext context = body.isEmpty() ? KMail::Composer::New :
                                                    KMail::Composer::NoTemplate;
-  KMail::Composer * cWin = KMail::makeComposer( msg, context );
+  KMail::Composer * cWin = KMail::makeComposer( msg, false, false, context );
   if ( !hidden ) {
     cWin->show();
     // Activate window - doing this instead of KWindowSystem::activateWindow(cWin->winId());
@@ -850,7 +851,7 @@ QDBusObjectPath KMKernel::newMessage( const QString &to,
   parser.setIdentityManager( identityManager() );
   parser.process( msg, folder ? folder->collection() : Akonadi::Collection() );
 
-  KMail::Composer *win = makeComposer( msg, KMail::Composer::New, id );
+  KMail::Composer *win = makeComposer( msg, false, false, KMail::Composer::New, id );
 
   //Add the attachment if we have one
   if ( !attachURL.isEmpty() && attachURL.isValid() ) {
@@ -1146,7 +1147,7 @@ void KMKernel::recoverDeadLetters()
 
       // Show the a new composer dialog for the message
       KMail::Composer * autoSaveWin = KMail::makeComposer();
-      autoSaveWin->setMsg( autoSaveMessage, false );
+      autoSaveWin->setMessage( autoSaveMessage, false, false, false );
       autoSaveWin->setAutoSaveFileName( filename );
       autoSaveWin->show();
       autoSaveFile.close();
@@ -1349,10 +1350,11 @@ void KMKernel::action( bool mailto, bool check, const QString &to,
                        const KUrl::List &attachURLs,
                        const QStringList &customHeaders )
 {
-  if ( mailto )
+  if ( mailto ) {
     openComposer( to, cc, bcc, subj, body, 0,
                   messageFile.pathOrUrl(), attachURLs.toStringList(),
                   customHeaders );
+  }
   else
     openReader( check );
 
