@@ -23,32 +23,24 @@
 */
 
 #include "summarywidget.h"
+#include "knotes/resourcemanager.h"
 
-#include <kontactinterfaces/core.h>
-#include <kontactinterfaces/plugin.h>
+#include <KCal/CalendarLocal>
 
-#include <knotes/resourcenotes.h>
-#include <knotes/resourcemanager.h>
+#include <KontactInterface/Core>
+#include <KontactInterface/Plugin>
 
-#include <kcal/calendarlocal.h>
+#include <KIconLoader>
+#include <KLocale>
+#include <KUrlLabel>
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kurllabel.h>
-#include <kstandarddirs.h>
-
-#include <QObject>
-#include <QLabel>
-#include <QLayout>
-#include <QVBoxLayout>
-#include <QPixmap>
-#include <QGridLayout>
 #include <QEvent>
+#include <QGridLayout>
+#include <QLabel>
+#include <QVBoxLayout>
 
-KNotesSummaryWidget::KNotesSummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
-  : Kontact::Summary( parent ), mLayout( 0 ), mPlugin( plugin )
+KNotesSummaryWidget::KNotesSummaryWidget( KontactInterface::Plugin *plugin, QWidget *parent )
+  : KontactInterface::Summary( parent ), mLayout( 0 ), mPlugin( plugin )
 {
   QVBoxLayout *mainLayout = new QVBoxLayout( this );
   mainLayout->setSpacing( 3 );
@@ -59,10 +51,10 @@ KNotesSummaryWidget::KNotesSummaryWidget( Kontact::Plugin *plugin, QWidget *pare
 
   mLayout = new QGridLayout();
   mainLayout->addItem( mLayout );
-  mLayout->setMargin( 3 );
+  mLayout->setSpacing( 3 );
   mLayout->setRowStretch( 6, 1 );
 
-  mCalendar = new KCal::CalendarLocal( QString::fromLatin1( "UTC" ) );
+  mCalendar = new CalendarLocal( QString::fromLatin1( "UTC" ) );
   KNotesResourceManager *manager = new KNotesResourceManager();
 
   QObject::connect( manager, SIGNAL(sigRegisteredNote(KCal::Journal*)),
@@ -89,7 +81,7 @@ void KNotesSummaryWidget::updateView()
   int counter = 0;
   QPixmap pm = loader.loadIcon( "knotes", KIconLoader::Small );
 
-  KCal::Journal::List::Iterator it;
+  Journal::List::Iterator it;
   if ( mNotes.count() ) {
     for ( it = mNotes.begin(); it != mNotes.end(); ++it ) {
 
@@ -107,6 +99,7 @@ void KNotesSummaryWidget::updateView()
       KUrlLabel *urlLabel = new KUrlLabel( (*it)->uid(), newtext, this );
       urlLabel->installEventFilter( this );
       urlLabel->setTextFormat( Qt::RichText );
+      urlLabel->setAlignment( Qt::AlignLeft );
       urlLabel->setWordWrap( true );
       mLayout->addWidget( urlLabel, counter, 1 );
       mLabels.append( urlLabel );
@@ -115,8 +108,8 @@ void KNotesSummaryWidget::updateView()
         urlLabel->setToolTip( (*it)->description().left( 80 ) );
       }
 
-      connect( urlLabel, SIGNAL(leftClickedUrl(const QString&)),
-               this, SLOT(urlClicked(const QString&)) );
+      connect( urlLabel, SIGNAL(leftClickedUrl(QString)),
+               this, SLOT(urlClicked(QString)) );
       counter++;
     }
 
@@ -127,7 +120,7 @@ void KNotesSummaryWidget::updateView()
       mLabels.append( noNotes );
   }
 
-  Q_FOREACH( label, mLabels ) { //krazy:exclude=foreach as label is a pointer
+  Q_FOREACH ( label, mLabels ) { //krazy:exclude=foreach as label is a pointer
     label->show();
   }
 }
@@ -153,7 +146,7 @@ bool KNotesSummaryWidget::eventFilter( QObject *obj, QEvent *e )
     }
   }
 
-  return Kontact::Summary::eventFilter( obj, e );
+  return KontactInterface::Summary::eventFilter( obj, e );
 }
 
 void KNotesSummaryWidget::addNote( KCal::Journal *j )
