@@ -22,6 +22,7 @@
 
 #include "../mailkernel.h"
 #include "../mdnadvicedialog.h"
+#include "../mailutil.h"
 
 #include <messagecomposer/messagefactory.h>
 #include <messagecomposer/messagesender.h>
@@ -102,11 +103,17 @@ void FilterAction::sendMDN( const Akonadi::Item &item, KMime::MDN::DispositionTy
   if ( !msg )
     return;
 
+
+
   const QPair<bool, KMime::MDN::SendingMode> mdnSend = MDNAdviceHelper::instance()->checkAndSetMDNInfo( item, type, true );
   if ( mdnSend.first ) {
     const int quote =  MessageViewer::GlobalSettings::self()->quoteMessage();
+    QString receiptTo =  msg->headerByType("Disposition-Notification-To") ? msg->headerByType("Disposition-Notification-To")->asUnicodeString() : QString();
+    if( receiptTo.isEmpty() ) 
+      return;
     MessageComposer::MessageFactory factory( msg, Akonadi::Item().id() );
     factory.setIdentityManager( KernelIf->identityManager() );
+    factory.setFolderIdentity( MailCommon::Util::folderIdentity( item ) );
 
     const KMime::Message::Ptr mdn = factory.createMDN( KMime::MDN::AutomaticAction, type, mdnSend.second, quote, modifiers );
     if ( mdn ) {
