@@ -156,8 +156,6 @@ void Message::ComposerViewBase::setMessage ( const KMime::Message::Ptr& msg )
   MessageViewer::ObjectTreeParser otp( &emptySource );//All default are ok
   otp.parseObjectTree( msgContent );
 
-  m_editor->setPlainText( otp.plainTextContent() );
-
   // Load the attachments
   MessageCore::AttachmentCollector ac;
   ac.collectAttachmentsFrom( msgContent );
@@ -180,6 +178,8 @@ void Message::ComposerViewBase::setMessage ( const KMime::Message::Ptr& msg )
     m_editor->setHtml( otp.htmlContent() );
     emit enableHtml();
     collectImages( m_msg.get() );
+  } else {
+    m_editor->setPlainText( otp.plainTextContent() );
   }
 
   if ( m_msg->headerByType( "X-KMail-CursorPos" ) ) {
@@ -494,11 +494,19 @@ QList< Message::Composer* > Message::ComposerViewBase::generateCryptoMessages ()
 
       composers.append( composer );
     }
+  } else if( !signSomething && !encryptSomething ) {
+     Message::Composer* composer =  new Message::Composer;
+     composers.append( composer );
+     //If we canceled sign or encrypt be sure to change status in attachment.
+     markAllAttachmentsForSigning(false);
+     markAllAttachmentsForSigning(false);
   }
 
+
   if( composers.isEmpty() && ( signSomething || encryptSomething ) )
     Q_ASSERT_X( false, "ComposerViewBase::fillCryptoInfo" , "No concrete sign or encrypt method selected");
 
+
   return composers;
 }
 
@@ -1472,4 +1480,23 @@ bool Message::ComposerViewBase::showKeyApprovalDialog()
 }
 
 
+void Message::ComposerViewBase::markAllAttachmentsForSigning(bool sign)
+{
+  foreach( MessageCore::AttachmentPart::Ptr attachment, m_attachmentModel->attachments() ) {
+    if( attachment->isSigned() ) {
+       attachment->setSigned(sign);
+    }
+  }
+}
+
+void Message::ComposerViewBase::markAllAttachmentsForEncryption(bool encrypt)
+{
+  foreach( MessageCore::AttachmentPart::Ptr attachment, m_attachmentModel->attachments() ) {
+    if( attachment->isEncrypted() ) {
+        attachment->setEncrypted(encrypt);
+    }
+  }
+}
+
+
 #include "composerviewbase.moc"
