@@ -25,6 +25,8 @@
 #include <KDE/KMenu>
 #include <KDE/KXMLGUIClient>
 
+#include <KToggleAction>
+
 #include <QtCore/QAbstractItemModel>
 #include <QtGui/QAbstractProxyModel>
 #include <QtGui/QItemSelectionModel>
@@ -69,6 +71,7 @@ public:
   void moveTabRight();
   void moveTabBackward();
   void moveTabForward();
+  void changeQuicksearchVisibility(bool);
   QItemSelection mapSelectionToSource( const QItemSelection &selection ) const;
   QItemSelection mapSelectionFromSource( const QItemSelection &selection ) const;
   void updateTabControls();
@@ -182,6 +185,14 @@ void Pane::setXmlGuiClient( KXMLGUIClient *xmlGuiClient )
 {
   d->mXmlGuiClient = xmlGuiClient;
 
+  KToggleAction * const showHideQuicksearch = new KToggleAction( i18n( "Show Quick Search Bar" ), this );
+  showHideQuicksearch->setShortcut( Qt::CTRL + Qt::Key_H );
+  showHideQuicksearch->setChecked( Core::Settings::showQuickSearch() );
+
+  d->mXmlGuiClient->actionCollection()->addAction( QLatin1String( "show_quick_search" ), showHideQuicksearch );
+  connect( showHideQuicksearch, SIGNAL(triggered(bool)), this, SLOT(changeQuicksearchVisibility(bool)) );
+
+
   for ( int i=0; i<count(); i++ ) {
     Widget *w = qobject_cast<Widget *>( widget( i ) );
     w->setXmlGuiClient( d->mXmlGuiClient );
@@ -536,6 +547,16 @@ void Pane::Private::closeTab( QWidget *w )
   updateTabControls();
 }
 
+
+void Pane::Private::changeQuicksearchVisibility(bool show)
+{
+    for ( int i=0; i<q->count(); i++ ) {
+      Widget *w = qobject_cast<Widget *>( q->widget( i ) );
+      w->changeQuicksearchVisibility(show);
+    }
+}
+
+
 bool Pane::eventFilter( QObject *object, QEvent *event )
 {
   if ( event->type() == QEvent::MouseButtonPress ) {
@@ -568,6 +589,8 @@ void Pane::Private::onCurrentTabChanged()
 void Pane::Private::onTabContextMenuRequest( const QPoint &pos )
 {
   QTabBar *bar = q->tabBar();
+  if ( q->count() <= 1 ) return;
+
   int index = bar->tabAt( bar->mapFrom( q, pos ) );
   if ( index == -1 ) return;
 
@@ -937,4 +960,12 @@ void Pane::updateTagComboBox()
 }
 
 
+bool Pane::searchEditHasFocus() const
+{
+  Widget *w = static_cast<Widget*>( currentWidget() );
+  if ( w )
+    return w->searchEditHasFocus();
+  return false;
+}
+
 #include "pane.moc"
